@@ -1,5 +1,6 @@
 import base64
 import time
+import uuid
 from google.protobuf.empty_pb2 import Empty
 
 import vegaapiclient as vac
@@ -13,6 +14,7 @@ from .fixtures import (  # noqa: F401
     walletname,
     walletpassphrase,
 )
+from .helpers import check_response
 
 
 def test_SubmitOrder(
@@ -35,7 +37,7 @@ def test_SubmitOrder(
 
     # Wait until funds are in accounts
     x = 0
-    maxwait = 20  # seconds
+    maxwait = 300  # seconds
     while True:
         request = vac.api.trading.PartyAccountsRequest(
             partyID=pubKey,
@@ -49,11 +51,12 @@ def test_SubmitOrder(
         if n > 0:
             print(f"Accounts: {response.accounts}")
         if n == 1 and response.accounts[0].balance == amt:
+            # Log time taken
+            # with open("/tmp/log", "a") as fh:
+            #     fh.write(f"{x}\n")
             break
         if x >= maxwait:
-            assert (
-                False
-            ), f"Failed to see {amt} {assetID} in {pubKey}'s general account"
+            assert False, f"Failed to see {amt} {assetID} in {pubKey}'s general account"
         time.sleep(1)
         x += 1
 
@@ -69,14 +72,17 @@ def test_SubmitOrder(
             size=1,
             timeInForce=vac.vega.Order.TimeInForce.TIF_GTT,
             type=vac.vega.Order.Type.TYPE_LIMIT,
+            reference=str(uuid.uuid4()),
         )
     )
-    response = trading.PrepareSubmitOrder(request)
-    blob = response.blob
+    # Either: Prepare the SubmitOrder using the Vega node
+    # blob = trading.PrepareSubmitOrder(request, contact_node=True).blob
+    # Or: Prepare the SubmitOrder ourselves
+    blob = trading.PrepareSubmitOrder(request, contact_node=False).blob
 
     # Sign the tx
-    r = walletclient.signtx(base64.b64encode(blob).decode("ascii"), pubKey)
-    assert r.status_code == 200
+    r = walletclient.signtx(base64.b64encode(blob).decode("ascii"), pubKey, False)
+    check_response(r)
     signedTx = r.json()["signedTx"]
 
     # Submit the signed transaction
